Function to extract the covariance parameters from an SVC_mle
or SVC_selectionobject.
Extact Covariance Parameters
Function to extract the covariance parameters from an SVC_mle
or SVC_selectionobject.
cov_par(...)# S3 method for SVC_mle
cov_par(object, ...)
# S3 method for SVC_selection
cov_par(object, ...)
further arguments
SVC_mle or SVC_selection object
vector with covariance parameters with the following attributes:
"GRF", charachter, describing the covariance function used for
the GP, see SVC_mle_control.
"tapering", either NULL if no tapering is applied of
the taper range.