Method to extract the computed (penalized) log (profile) Likelihood from an SVC_mle object.
# S3 method for SVC_mle
logLik(object, ...)an object of class logLik with attributes
"penalized", logical, if the likelihood (FALSE) or some penalized likelihood (TRUE) was optimized.
"profileLik", logical, if the optimization was done using the profile likelihood (TRUE) or not.
"nobs", integer of number of observations
"df", integer of how many parameters were estimated. Note: This includes only the covariance parameters if the profile likelihood was used.
SVC_mle object
further arguments
Jakob Dambon