Function to extract the covariance parameters from an SVC_mle object.
Extact Covariance Parameters
Function to extract the covariance parameters from an SVC_mle object.
cov_par(object, ...)SVC_mle object
further arguments
vector with covariance parameters and attributes what kind
"GRF", charachter, describing the GRF used, see SVC_mle_control.
"tapering", either NULL if no tapering is applied of the taper range.